@@ -1,7 +1,7 @@
 
 from io import BytesIO
 
-from mox3.mox import MoxTestBase, IsA
+from mox import MoxTestBase, IsA
 
 from slimta.edge.wsgi import WsgiEdge, WsgiValidators
 from slimta.envelope import Envelope
